@@ -4,6 +4,7 @@
  *                2003 Jasper Huijsmans (huysmans@users.sourceforge.net)
  *                2003,2006 Benedikt Meurer (benny@xfce.org)
  *                2005,2006 Jean-François Wauthy (pollux@xfce.org)
+ *                2007 Cody A.W. Somerville <cody-somerville@ubuntu.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -411,13 +412,22 @@ main (int argc, char **argv)
   GtkWidget *info_help_button;
   GdkPixbuf *logo_pb;
 
+  if(argc >= 2 && !strcmp (argv[1], "--xfce-version")) {
+#ifdef RELEASE_LABEL
+    g_printf ("%s (%s)\n", xfce_version_string (), RELEASE_LABEL);
+#else
+    g_printf ("%s\n", xfce_version_string ());
+#endif
+    exit (0);
+  }
+
   xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
 
   gtk_init (&argc, &argv);
 
   info = xfce_titled_dialog_new ();
   gtk_window_set_title (GTK_WINDOW (info), _("About Xfce 4"));
-  xfce_titled_dialog_set_subtitle (XFCE_TITLED_DIALOG (info), _("Copyright 2002-2007 by Olivier Fourdan"));
+  xfce_titled_dialog_set_subtitle (XFCE_TITLED_DIALOG (info), _("Copyright 2002-2008 by Olivier Fourdan"));
   gtk_dialog_set_has_separator (GTK_DIALOG (info), FALSE);
   gtk_window_stick (GTK_WINDOW (info));
 
